@@ -210,7 +210,10 @@ def _check_dsk(dsk):
     assert not non_one, non_one
 
 
-def assert_eq_shape(a, b, check_nan=True):
+def assert_eq_shape(a, b, check_ndim=True, check_nan=True):
+    if check_ndim:
+        assert len(a) == len(b)
+
     for aa, bb in zip(a, b):
         if math.isnan(aa) or math.isnan(bb):
             if check_nan:
@@ -219,7 +222,7 @@ def assert_eq_shape(a, b, check_nan=True):
             assert aa == bb
 
 
-def _check_chunks(x, scheduler=None):
+def _check_chunks(x, check_ndim=True, scheduler=None):
     x = x.persist(scheduler=scheduler)
     for idx in itertools.product(*(range(len(c)) for c in x.chunks)):
         chunk = x.dask[(x.name,) + idx]
@@ -228,7 +231,9 @@ def _check_chunks(x, scheduler=None):
         if not hasattr(chunk, "dtype"):
             chunk = np.array(chunk, dtype="O")
         expected_shape = tuple(c[i] for c, i in zip(x.chunks, idx))
-        assert_eq_shape(expected_shape, chunk.shape, check_nan=False)
+        assert_eq_shape(
+            expected_shape, chunk.shape, check_ndim=check_ndim, check_nan=False
+        )
         assert (
             chunk.dtype == x.dtype
         ), "maybe you forgot to pass the scheduler to `assert_eq`?"
@@ -236,7 +241,12 @@ def _check_chunks(x, scheduler=None):
 
 
 def _get_dt_meta_computed(
-    x, check_shape=True, check_graph=True, check_chunks=True, scheduler=None
+    x,
+    check_shape=True,
+    check_graph=True,
+    check_chunks=True,
+    check_ndim=True,
+    scheduler=None,
 ):
     x_original = x
     x_meta = None
@@ -250,7 +260,7 @@ def _get_dt_meta_computed(
         x_meta = getattr(x, "_meta", None)
         if check_chunks:
             # Replace x with persisted version to avoid computing it twice.
-            x = _check_chunks(x, scheduler=scheduler)
+            x = _check_chunks(x, check_ndim=check_ndim, scheduler=scheduler)
         x = x.compute(scheduler=scheduler)
         x_computed = x
         if hasattr(x, "todense"):
@@ -276,6 +286,7 @@ def assert_eq(
     check_graph=True,
     check_meta=True,
     check_chunks=True,
+    check_ndim=True,
     check_type=True,
     check_dtype=True,
     equal_nan=True,
@@ -295,6 +306,7 @@ def assert_eq(
         check_shape=check_shape,
         check_graph=check_graph,
         check_chunks=check_chunks,
+        check_ndim=check_ndim,
         scheduler=scheduler,
     )
     b, bdt, b_meta, b_computed = _get_dt_meta_computed(
@@ -302,6 +314,7 @@ def assert_eq(
         check_shape=check_shape,
         check_graph=check_graph,
         check_chunks=check_chunks,
+        check_ndim=check_ndim,
         scheduler=scheduler,
     )
 
