@@ -749,7 +749,7 @@ def test_set_index_timezone():
         assert not d2.divisions[0] == s2badtype[0]
     else:
         with pytest.raises(TypeError):
-            d2.divisions[0] == s2badtype[0]
+            assert d2.divisions[0] == s2badtype[0]
 
 
 def test_set_index_npartitions():
@@ -1182,6 +1182,17 @@ def test_set_index_overlap_2():
     assert ddf2.npartitions == 8
 
 
+def test_set_index_overlap_does_not_drop_rows_when_divisions_overlap():
+    # https://github.com/dask/dask/issues/9339
+    df = pd.DataFrame({"ts": [1, 1, 2, 2, 3, 3, 3, 3], "value": "abc"})
+    ddf = dd.from_pandas(df, npartitions=3)
+
+    expected = df.set_index("ts")
+    actual = ddf.set_index("ts", sorted=True)
+
+    assert_eq(expected, actual)
+
+
 def test_compute_current_divisions_nan_partition():
     # Compute divisions 1 null partition
     a = d[d.a > 3].sort_values("a")
